@@ -1,7 +1,29 @@
 import docassemble.base.functions
-from docassemble.base.util import defined, value, showifdef, space_to_underscore
+from docassemble.base.util import (
+    defined,
+    value,
+    showifdef,
+    space_to_underscore,
+    Address,
+)
 import re
 
+__all__ = [
+    "shortenMe",
+    "thousands",
+    "tel",
+    "fa_icon",
+    "space",
+    "yes_no_unknown",
+    "number_to_letter",
+    "collapse_template",
+    "tabbed_templates_html",
+    "sum_if_defined",
+    "add_records",
+    "output_checkbox",
+    "nice_county_name",
+]
+
 
 class shortenMe:
     def __init__(self, originalURL):
@@ -107,6 +129,8 @@ def collapse_template(template, classname=None):
     """
     Insert HTML for a Bootstrap "collapse" div.
     """
+    if not template.subject_as_html(trim=True) and not template.content_as_html():
+        return ""
     if classname is None:
         classname = " bg-light"
     else:
@@ -184,3 +208,16 @@ def output_checkbox(
         return checked_value
     else:
         return unchecked_value
+
+
+def nice_county_name(address: Address) -> str:
+    """
+    If the county name contains the word "County", which Google Address
+    Autocomplete does by default, remove it.
+    """
+    if not hasattr(address, "county"):
+        return ""
+    if address.county.endswith(" County"):
+        return address.county[: -len(" County")]
+    else:
+        return address.county
